@@ -3,17 +3,17 @@ use std::{io::Read, path::PathBuf};
 
 use anyhow::Result;
 
+use dolby_vision::rpu::ConversionMode;
 use dolby_vision::rpu::dovi_rpu::DoviRpu;
 use dolby_vision::rpu::extension_metadata::blocks::{ExtMetadataBlock, ExtMetadataBlockLevel6};
 use dolby_vision::rpu::extension_metadata::{ColorPrimaries, MasteringDisplayPrimaries};
 use dolby_vision::rpu::generate::GenerateConfig;
 use dolby_vision::rpu::rpu_data_nlq::DoviELType;
-use dolby_vision::rpu::ConversionMode;
-use hevc_parser::hevc::{NALUnit, NAL_UNSPEC62};
+use hevc_parser::hevc::{NAL_UNSPEC62, NALUnit};
+use hevc_parser::io::StartCodePreset;
 
 use crate::commands::GenerateArgs;
 use crate::dovi::generator::Generator;
-use crate::dovi::WriteStartCodePreset;
 
 pub fn _parse_file(input: PathBuf) -> Result<(Vec<u8>, DoviRpu)> {
     let mut f = File::open(input)?;
@@ -40,7 +40,7 @@ fn _debug(data: &[u8]) -> Result<()> {
     NALUnit::write_with_preset(
         &mut file,
         &data[2..],
-        WriteStartCodePreset::Four.into(),
+        StartCodePreset::Four,
         NAL_UNSPEC62,
         true,
     )?;
@@ -716,12 +716,15 @@ fn generate_full() -> Result<()> {
 #[cfg(target_os = "linux")]
 #[test]
 fn generate_full_hdr10plus() -> Result<()> {
+    use crate::commands::generate::ArgHdr10PlusPeakBrightnessSource;
+
     let args = GenerateArgs {
         json_file: Some(PathBuf::from(
             "./assets/generator_examples/no_duration.json",
         )),
         rpu_out: Some(PathBuf::from("/dev/null")),
         hdr10plus_json: Some(PathBuf::from("./assets/tests/hdr10plus_metadata.json")),
+        hdr10plus_peak_source: Some(ArgHdr10PlusPeakBrightnessSource::MaxScl),
         ..Default::default()
     };
 
@@ -1119,3 +1122,15 @@ fn source_p5_to_p8_001_end_crc32() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn profile20_apple() -> Result<()> {
+    let (original_data, dovi_rpu) =
+        _parse_file(PathBuf::from("./assets/tests/profile20_apple.bin"))?;
+    assert_eq!(dovi_rpu.dovi_profile, 5);
+    let parsed_data = dovi_rpu.write_hevc_unspec62_nalu()?;
+
+    assert_eq!(&original_data[4..], &parsed_data[2..]);
+
+    Ok(())
+}
